
from setuptools import setup


setup(
    name='hfile',
    version='1.0.7',
    license='MIT',
    py_modules = ['hfile'],
    packages=['hfile'],
    install_requires=['click', 'colorama'],
    classifiers=[
    # How mature is this project? Common values are
    #   3 - Alpha
    #   4 - Beta
    #   5 - Production/Stable
    'Development Status :: 3 - Alpha',

    # Indicate who your project is intended for
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',

    # Pick your license as you wish (should match "license" above)
     'License :: OSI Approved :: MIT License',

    # Specify the Python versions you support here. In particular, ensure
    # that you indicate whether you support Python 2, Python 3 or both.
    'Programming Language :: Python :: 2',
    'Programming Language :: Python :: 2.6',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.2',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',

    ],
    entry_points={
        'console_scripts': [
            'hfile=hfile.cli:main',
        ],
    },
)


import os


def walkdirectory(directory):
    fileslist = list()
    for dirpath, dirnames, filenames in os.walk(directory):
        for filename in filenames:
            checkfile = os.path.join(dirpath, filename)
            if os.path.isfile(checkfile):
                fileslist.append(checkfile)
    return fileslist